@@ -23,6 +23,7 @@ my $const = Locale::TextDomain::OO::Util::Constants->instance;
     )
     ->Indent(1)
     ->Quotekeys(0)
+    ->Sortkeys(1)
     ->Useqq(1)
     ->Dump;
 
@@ -33,7 +34,7 @@ __END__
 Output:
 
 $constants = {
-  plural_separator => "\0",
+  lexicon_key_separator => ":",
   msg_key_separator => "\4",
-  lexicon_key_separator => ":"
+  plural_separator => "\0"
 };
