@@ -118,6 +118,7 @@ my $key_util = Locale::TextDomain::OO::Util::JoinSplitLexiconKeys->instance;
     )
     ->Indent(1)
     ->Quotekeys(0)
+    ->Sortkeys(1)
     ->Terse(1)
     ->Useqq(1)
     ->Dump;
@@ -128,18 +129,6 @@ __END__
 
 Output:
 
-$constants = {
-  plural_separator => "\0",
-  msg_key_separator => "\4",
-  lexicon_key_separator => ":"
-};
-EOT
-    },
-    {
-        test   => '02_join_split',
-        path   => 'example',
-        script => '-I../lib 02_join_split.pl',
-        result => <<'EOT',
 [
   "i-default::",
   "de-de::",
@@ -148,27 +137,27 @@ EOT
   "de-de:::my project:my subproject",
   {},
   {
+    category => "",
     domain => "",
-    language => "de-de",
-    category => ""
+    language => "de-de"
   },
   {
+    category => "my category",
     domain => "my domain",
     language => "de-de",
-    project => "my project",
-    category => "my category"
+    project => "my project"
   },
   {
+    category => "",
     domain => "",
     language => "de-de",
-    project => "my project",
-    category => ""
+    project => "my project"
   },
   {
+    category => "",
     domain => "",
     language => "de-de",
-    project => "my project:my subproject",
-    category => ""
+    project => "my project:my subproject"
   },
   "",
   {},
@@ -187,11 +176,11 @@ EOT
   {
     msgctxt => "my context",
     msgid => "my singular",
+    msgid_plural => "my plural",
     msgstr_plural => [
       "tr singular",
       "tr plural"
-    ],
-    msgid_plural => "my plural"
+    ]
   },
   [
     "my singular\0my plural\4my context",
@@ -205,11 +194,11 @@ EOT
   {
     msgctxt => "my context",
     msgid => "my singular",
+    msgid_plural => "my plural",
     msgstr_plural => [
       "tr singular",
       "tr plural"
-    ],
-    msgid_plural => "my plural"
+    ]
   },
   [
     "my singular{PLURAL_SEPARATOR}my plural{MSG_KEY_SEPARATOR}my context",
