@@ -16,12 +16,14 @@ my $extractor = Locale::TextDomain::OO::Util::ExtractHeader->instance;
             $extractor->extract_header_msgstr(<<'EOT'),
 Content-Type: text/plain; charset=UTF-8
 Plural-Forms: nplurals=2; plural=n != 1
+X-Lexicon-Class: Foo::Bar
 EOT
         ],
         [ qw( extract ) ],
     )
     ->Indent(1)
     ->Quotekeys(0)
+    ->Sortkeys(1)
     ->Useqq(1)
     ->Dump;
 
@@ -32,8 +34,9 @@ __END__
 Output:
 
 $extract = {
-  plural => "n != 1",
-  plural_code => sub { "DUMMY" },
   charset => "UTF-8",
-  nplurals => 2
+  lexicon_class => "Foo::Bar",
+  nplurals => 2,
+  plural => "n != 1",
+  plural_code => sub { "DUMMY" }
 };
