@@ -8,7 +8,7 @@ use Locale::TextDomain::OO::Util::Constants;
 use Safe;
 use namespace::autoclean;
 
-our $VERSION = '3.005';
+our $VERSION = '3.006';
 
 sub instance {
     return __PACKAGE__;
@@ -109,19 +109,25 @@ sub extract_header_msgstr {
         $
     }xms
         or confess 'Content-Type with charset not found in header';
+    my ( $lexicon_class ) = $header_msgstr =~ m{
+        ^ X-Lexicon-Class: \s* ( \S* ) \s* $
+    }xms;
+    # ToDo: remove because multiplural was a too complicated idea
     my ( $multiplural_nplurals ) = $header_msgstr =~ m{
         ^ X-Multiplural-Nplurals: [ ]* ( \d+ ) [ ]* $
     }xms;
 
     return {(
-        nplurals    => $nplurals__code_ref->($plural_forms),
-        plural      => $plural__code_ref->($plural_forms),
-        plural_code => $plural_code__code_ref->($plural_forms),
-        charset     => $charset,
-        (
-            $multiplural_nplurals
-            ? ( multiplural_nplurals => $multiplural_nplurals )
-            : ()
+        nplurals                 => $nplurals__code_ref->($plural_forms),
+        plural                   => $plural__code_ref->($plural_forms),
+        plural_code              => $plural_code__code_ref->($plural_forms),
+        charset                  => $charset,
+        ! $lexicon_class ? () : (
+            lexicon_class        => $lexicon_class,
+        ),
+        # ToDo: remove because multiplural was a too complicated idea
+        ! $multiplural_nplurals ? () : (
+            multiplural_nplurals => $multiplural_nplurals,
         ),
     )};
 }
@@ -139,7 +145,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-TextD
 
 =head1 VERSION
 
-3.005
+3.006
 
 =head1 DESCRIPTION
 
@@ -177,10 +183,11 @@ See: https://rt.cpan.org/Ticket/Display.html?id=99563
 
 That hash_ref contains:
 
-    nplurals    => $count_of_plural_forms,
-    plural      => $the_original_formula,
-    plural_code => $code_ref__to_select_the_right_plural_form,
-    charset     => $charset,
+    nplurals      => $count_of_plural_forms,
+    plural        => $the_original_formula,
+    plural_code   => $code_ref__to_select_the_right_plural_form,
+    charset       => $charset,
+    lexicon_class => 'from X-Lexicon-Class',
 
 =head1 EXAMPLE
 
@@ -225,7 +232,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2014 - 2015,
+Copyright (c) 2014 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
